@@ -1,4 +1,6 @@
-# Copyright (C) 2003-2007, 2009 Nominum, Inc.
+# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
+
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -14,7 +16,10 @@
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 import dns.rdtypes.nsbase
+import dns.immutable
 
+
+@dns.immutable.immutable
 class PTR(dns.rdtypes.nsbase.NSBase):
+
     """PTR record"""
-    pass
